AkoOsmBottomSheet class

AkoOsmBottomSheet is shows a OSMFlutter Map inside of a resizable bottom sheet.

Constructors

AkoOsmBottomSheet({required AkoOsmBottomSheetOptions options})

Properties

hashCode int
The hash code for this object.
no setterinherited
options AkoOsmBottomSheetOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showBottomSheet<T>(BuildContext context) Future<T?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited