AkoOsmBottomSheetOptions class

AkoOsmBottomSheetOptions provides configuration for AkoOsmBottomSheet.

Constructors

AkoOsmBottomSheetOptions({required OSMFlutter map, String textMapTitle = "Map"})

Properties

hashCode int
The hash code for this object.
no setterinherited
map OSMFlutter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textMapTitle String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited