AkoOsmMapOptions class

AkoOsmMapOptions provides configuration for AkoOsmMap.

Constructors

AkoOsmMapOptions({bool allowBottomSheet = true, String textSheetTitle = "Map", String textMapNotFound = "Map could not be loaded.", String textMapOpenSheet = "double-tap to open map"})

Properties

allowBottomSheet bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textMapNotFound String
final
textMapOpenSheet String
final
textSheetTitle String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited