SearchInfo class

Constructors

SearchInfo({GeoPoint? point, Address? address})
SearchInfo.fromPhotonAPI(Map data)

Properties

address → Address?
final
hashCode → int
The hash code for this object.
no setterinherited
point → GeoPoint?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited